//Конкатенация индексов
function [indexMatrix]=ConcatIndexesRange(minIndexes,..//Минимальные значения индексов
                                          maxIndexes,..//Максимальные значения индексов
                                          stepIndexes,..//Шаги индексов
                                          elementsIndexes,..//Элементы в качестве индексов
                                          grid..//Необходимость размножения индексов
                                          )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 1 then
        error('The function ConcatIndexesRange takes 1, 2, 3, 4 or 5 arguments');
    end
    select nArg
    case 1 then
        maxIndexes = minIndexes;
        minIndexes = ones(maxIndexes);//По умолчанию минимумы берем единицы
        stepIndexes = ones(maxIndexes);//По умолчанию шаг берем единицы
        elementsIndexes = [];//По умолчанию берем пустыми
        grid = %t;//По умолчанию делаем сетку
    case 2 then
        if type(maxIndexes) == 4 then
            grid = maxIndexes;
            maxIndexes = minIndexes;
            minIndexes = ones(maxIndexes);//По умолчанию минимумы берем единицы
        else
            grid = %t;//По умолчанию делаем сетку
        end
        stepIndexes = ones(maxIndexes);//По умолчанию шаг берем единицы
        elementsIndexes = [];//По умолчанию берем пустыми
    case 3 then
        if type(stepIndexes) == 4 then
            grid = stepIndexes;
            stepIndexes = ones(maxIndexes);//По умолчанию шаг берем единицы
        else
            grid = %t;//По умолчанию делаем сетку
        end
        elementsIndexes = [];//По умолчанию берем пустыми
    case 4 then
        if type(elementsIndexes) == 4 then
            grid = elementsIndexes;
            elementsIndexes = [];//По умолчанию берем пустыми
        else
            grid = %t;//По умолчанию делаем сетку
        end
    end
    
    //Проверяем корректность аргументов
    if (type(minIndexes) ~= type(maxIndexes)) ||..
       (type(minIndexes) ~= type(stepIndexes)) then
        error('The function''s CreateIndexesFromDiapasons arguments'' minIndexes, maxIndexes and stepIndexes types must be equality');
    end
    nIndexes = size(minIndexes,'*');
    if (nIndexes ~= size(maxIndexes,'*')) ||..
       (nIndexes ~= size(stepIndexes,'*')) then
        error('The function''s CreateIndexesFromDiapasons arguments'' minIndexes, maxIndexes and stepIndexes sizes must be equality');
    end
    if (~isempty(elementsIndexes)) && (type(minIndexes) ~= 1) then
        error('The function''s CreateIndexesFromDiapasons arguments'' minIndexes, maxIndexes and stepIndexes must be integer');
    end
    
    //Выполняем конкатенацию
    listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes,..
                                             stepIndexes,..
                                             elementsIndexes);
    indexMatrix = ConcatIndexes(listIndexes,grid);
endfunction
