//Конкатенация индексов
function [listIndexes]=CreateIndexesFromDiapasons(minIndexes,..//Минимальные значения индексов
                                                  maxIndexes,..//Максимальные значения индексов
                                                  stepIndexes,..//Шаги индексов
                                                  elementsIndexes..//Элементы в качестве индексов
                                                  )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 1 then
        error('The function CreateIndexesFromDiapasons takes 1, 2, 3 or 4 arguments');
    end
    switch nArg
    case 1 then
        maxIndexes = minIndexes;
        stepIndexes = ones(minIndexes);
        minIndexes = ones(minIndexes);
        elementsIndexes = [];
    case 2 then
        stepIndexes = ones(minIndexes);
        elementsIndexes = [];
    case 3 then
        elementsIndexes = [];
    end
    
    //Приводим минимумы, максимумы, шаги и элементы к матрицам-строкам
    minIndexes = matrix(minIndexes,1,-1);
    maxIndexes = matrix(maxIndexes,1,-1);
    stepIndexes = matrix(stepIndexes,1,-1);
    isEmElementsIndexes = isempty(elementsIndexes);
    if ~isEmElementsIndexes then
        elementsIndexes = matrix(elementsIndexes,-1,1);
    end
    
    //Проверяем корректность аргументов
    if (type(minIndexes) ~= type(maxIndexes)) ||..
       (type(minIndexes) ~= type(stepIndexes)) then
        error('The function''s CreateIndexesFromDiapasons arguments'' minIndexes, maxIndexes and stepIndexes types must be equality');
    end
    nIndexes = size(minIndexes,'*');
    if (nIndexes ~= size(maxIndexes,'*')) ||..
       (nIndexes ~= size(stepIndexes,'*')) then
        error('The function''s CreateIndexesFromDiapasons arguments'' minIndexes, maxIndexes and stepIndexes sizes must be equality');
    end
    if (~isEmElementsIndexes) && (type(minIndexes) ~= 1) then
        error('The function''s CreateIndexesFromDiapasons arguments'' minIndexes, maxIndexes and stepIndexes must be integer');
    end
    
    //Формируем cell-массив индексов
    listIndexes = list();
    if isEmElementsIndexes then
        for ind=1:nIndexes
            listIndexes = lstcat(listIndexes,[minIndexes(ind):stepIndexes(ind):maxIndexes(ind)]');
        end
    else
        for ind=1:nIndexes
            listIndexes = lstcat(listIndexes,elementsIndexes([minIndexes(ind):stepIndexes(ind):maxIndexes(ind)]));
        end
    end
endfunction
