//Конкатенация индексов
function [fileIndexNames,..
          indexMatrix]=FileNamesIndexesRange(beginPartName,..//Начальная часть имени файла
                                             endPartName,..//Конечная часть имени файла
                                             indexSepName,..//Ращзделитель индексов
                                             extFile,..//Расширение файла
                                             minIndexes,..//Минимальные значения индексов
                                             maxIndexes,..//Максимальные значения индексов
                                             stepIndexes,..//Шаги индексов
                                             elementsIndexes,..//Элементы в качестве индексов
                                             grid..//Необходимость сеточного размножения индексов
                                             )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 5 then
        error('The function FileNamesIndexesRange takes 5, 6, 7, 8 or 9 arguments');
    end
    
    //Проверяем корректность аргументов
    if (type(beginPartName) ~= 10) || (size(beginPartName,'*') > 1) then
        error('The argument beginPartName of function FileNamesIndexesRange must be scalar string');
    end
    if (type(endPartName) ~= 10) || (size(endPartName,'*') > 1) then
        error('The argument endPartName of function FileNamesIndexesRange must be scalar string');
    end
    if (type(indexSepName) ~= 10) || (size(indexSepName,'*') > 1) then
        error('The argument indexSepName of function FileNamesIndexesRange must be scalar string');
    end
    if (type(extFile) ~= 10) || (size(extFile,'*') > 1) then
        error('The argument extFile of function FileNamesIndexesRange must be scalar string');
    end
    
    //Проверяем аргументы в зависимости от числа аргументов и делаем конкатенацию
    select nArg
    case 5 then
        listIndexes = CreateIndexesFromDiapasons(minIndexes);//Получаем список индексов
        [fileIndexNames,..
         indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes);//Формируем локальное имя файла
    case 6 then
        if type(maxIndexes) == 4 then
            listIndexes = CreateIndexesFromDiapasons(minIndexes);//Получаем список индексов
            [fileIndexNames,..
             indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes,maxIndexes);//Формируем локальное имя файла
        else
            listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes);//Получаем список индексов
            [fileIndexNames,..
             indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes);//Формируем локальное имя файла
        end
    case 7 then
        if type(stepIndexes) == 4 then
            listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes);//Получаем список индексов
            [fileIndexNames,..
             indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes,stepIndexes);//Формируем локальное имя файла
        else
            listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes,stepIndexes);//Получаем список индексов
            [fileIndexNames,..
             indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes);//Формируем локальное имя файла
        end
    case 8 then
        if type(elementsIndexes) == 4 then
            listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes,stepIndexes);//Получаем список индексов
            [fileIndexNames,..
             indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes,elementsIndexes);//Формируем локальное имя файла
        else
            listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes,stepIndexes,elementsIndexes);//Получаем список индексов
            [fileIndexNames,..
             indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes);//Формируем локальное имя файла
        end
    else
        if type(grid) ~= 4 then
            error("The argument grid of function FileNamesIndexesRange must be boolean");
        end
        listIndexes = CreateIndexesFromDiapasons(minIndexes,maxIndexes,stepIndexes,elementsIndexes);//Получаем список индексов
        [fileIndexNames,..
         indexMatrix] = FileNamesIndexes(beginPartName,endPartName,indexSepName,extFile,listIndexes,grid);//Формируем локальное имя файла
    end
endfunction
